package com.goldenwater.slaj.ttsa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.ttsa.mapper.ObjTtsaMapper;
import com.goldenwater.slaj.ttsa.domain.ObjTtsa;
import com.goldenwater.slaj.ttsa.service.IObjTtsaService;

@Service
public class ObjTtsaServiceImpl implements IObjTtsaService {
    @Autowired
    private ObjTtsaMapper objTtsaMapper;

    @Override
    public ObjTtsa selectObjTtsaByGuid(String guid) {
        return objTtsaMapper.selectObjTtsaByGuid(guid);
    }

    @Override
    public List<ObjTtsa> selectObjTtsaList(ObjTtsa objTtsa) {
        return objTtsaMapper.selectObjTtsaList(objTtsa);
    }

    @Override
    public int insertObjTtsa(ObjTtsa objTtsa) {
        return objTtsaMapper.insertObjTtsa(objTtsa);
    }

    @Override
    public int updateObjTtsa(ObjTtsa objTtsa) {
        return objTtsaMapper.updateObjTtsa(objTtsa);
    }

    @Override
    public int deleteObjTtsaByGuid(String guid) {
        return objTtsaMapper.deleteObjTtsaByGuid(guid);
    }

    @Override
    public int deleteObjTtsaByGuids(String[] guids) {
        return objTtsaMapper.deleteObjTtsaByGuids(guids);
    }
}
